#/user/bin/sh python3
# verstort mar 2018

# summary:
# this requires python 3 or 2 with futures installed, and psutil installed
# search through this directory for psc files that haven't been compiled yet, or are out of date, compile them
# unless the user specifies files, then do just those

# usage:
# if you want to compile all new files, either missing PEX or new changes
#  nice -n 2 python3 compile_batch.py 
# if you want to force compile any specific files, add as parameters:
#  nice -n 2 python3 compile_batch.py a.psc b.psc c.psc
# if you want to force recompile all files that use a certain function:
#  nice -n 2 python3 compile_batch.py $(grep -il functionname *)
# if you want to recompile everything, regardless of if it needs to be recompiled:
#  nice -n 2 python3 compile_batch.py *

# location of the compiler script for compiling in a MO based environment
compilerscriptloc = "../../../../"

import glob
import os
import re
import sys
import subprocess
import time

# multithreading
from concurrent.futures import ThreadPoolExecutor 
#from futures import ThreadPoolExecutor 
cputhreads = 4 
tpe = ThreadPoolExecutor(cputhreads)

# nice up
# using all cores of a CPU is annoying if it blocks the rest of hte computer from working, 
#  so we use nice to lower the priortiy so it takes all available space cpu after the rest
#  of the machine is done doing what it needs to do first
if sys.platform == "win32": #usingwindows:
  # pulled from: https://stackoverflow.com/questions/1023038/change-process-priority-in-python-cross-platform
  # doesn't work with my bugged install because cannot install win32api to python3
  #import win32api,win32process,win32con
  #pid = win32api.GetCurrentProcesssId()
  #handle = win32.api.OpenProcess(win32.con.PROCESS_ALL_ACCESS, True, pid)
  #win32process.SetPriorityClass(handle, win32process.BELOW_NORMAL_PRIORITY_CLASS)
  import psutil
  p = psutil.Process(os.getpid())
  p.nice(psutil.BELOW_NORMAL_PRIORITY_CLASS)

else: # posix
  os.nice(5)

# parameter handling
if len(sys.argv) > 1:
  pscfiles = [ re.sub("\.psc", "", f) for f in  sys.argv[1:] ]
  pscfiles = [ f.split("\\")[-1] for f in pscfiles ]
else: # check the whole directory
  pscfiles = [ re.sub("\.psc", "", f) for f in glob.glob("*psc")]

# single file compile, passed as job to thread pool
#  future function
def compile_one_script(filename):
  call = "compile_with_sources_local.bat " + filename + ".psc \"" + os.getcwd() + "\""
  #print("starting compiling: " + filename + ", "+ call)
  # new console doesn't work, huh
  p = subprocess.Popen(call, shell=True, cwd=compilerscriptloc, stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE, creationflags=subprocess.CREATE_NEW_CONSOLE)
  # the \n is an [Enter] input, which is needed for the script to leave, we encode into byte format because dos
  output, err = p.communicate(input=("\n").encode())
  # output is byte coded too
  output = output.decode()
  err = err.decode()

  if "1 failed" in output:
    if err != None:
      print("Script " + filename + " failed to compile:")
      print(re.sub("^[A-Z]:.*crde", "  ", err, flags=re.MULTILINE))
      sys.stdout.flush()
  elif len(output) == 0:
    print(filename + " has no putput!")
  else:
    print(filename + " has finished compiling successfully.")
    sys.stdout.flush()
  #time.sleep(1)



todo_compile = []

# look for files we need to compile
# we only check if files need to be recompiled if we're searching a whole directory,
# if given files directly, then we skip this
if len(sys.argv) <= 1:
  for f in pscfiles:
    try:
      #print("for file: " + f + " modification date is: " + str(os.path.getmtime(f + ".psc")))
      #print("pex     : " + f + " modification date is: " + str(os.path.getmtime(f + ".pex/..")))
      srcdate = os.path.getmtime(f + ".psc") 
      pexdate = os.path.getmtime("../" + f + ".pex")
      if srcdate > pexdate:
        print("we have a newer source! " + f + " is [" + str((srcdate - pexdate) / 60 /60 /24) + "] days older")
        todo_compile.append( f )
      elif len(sys.argv) > 1: # user chose this file specifically
        print("file [" + f + "] does not need to be recompiled")
      sys.stdout.flush() 

    except WindowsError:
      print ("No pex file found! " + f)
      todo_compile.append(f)
  # spacers
  print()
else:
  todo_compile = pscfiles
  

print("List of files to compile:")
print(todo_compile)

# spacers
print()

sys.stdout.flush() # otherwise python won't print until we get more output from the jobs

# job throttle
#  last time I tried, concurent futures crashed when I gave the TPE > 10000 files
#  probably unlikely to need to compile that many, but possible edge case we should avoid
indicator_jobs = []
while len(todo_compile) > 1:
  #cleaning
  for i in indicator_jobs:
    if i.done():
      indicator_jobs.remove(i)
  try:
    if len(indicator_jobs ) <= 2 and len(todo_compile) >= 7:
      # low on jobs, add jobs, where every N jobs gets an indicator job
      for cluster in range(cputhreads * 3):
        #print("doing another 4")
        indicator_jobs.append(tpe.submit(compile_one_script, todo_compile.pop()))
        #for regularjob in range((cputhreads *3 ) - 1 ):
        tpe.submit(compile_one_script, todo_compile.pop())
        tpe.submit(compile_one_script, todo_compile.pop())
        tpe.submit(compile_one_script, todo_compile.pop())
    elif len(indicator_jobs) <= 2:
      for remainingfile in todo_compile:
        tpe.submit(compile_one_script, todo_compile.pop())
  except IndexError:
    print("reached end of the list, waiting for compiling to finish")
      
  time.sleep(1)

tpe.shutdown(wait=True)

#compile_one_script(todo_compile[0])

print("Finished compiling all files.")

